(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[6308],{29237:function(e,n,t){"use strict";var i=t(9518),r=t(67971),d=t(86673),o=t(19711),c=t(31969),a=t(73942),l=t(37391),u=t(49125),h=t(28598),s=(0,i.css)(["padding:","px;padding-bottom:","px;padding-top:","px;"],2*u.iI,1.5*u.iI,1.5*u.iI),f=i.default.div.withConfig({displayName:"Panel__PanelStyle",componentId:"sc-1ct8cgl-0"})(["border-radius:","px;overflow:hidden;width:100%;"," "," "," "," "," ",""],a.n_,(function(e){return"\n    background-color: ".concat((e.theme.background||c.Z.background).panel,";\n    border: 1px solid ").concat((e.theme.interactive||c.Z.interactive).defaultBorder,";\n  ")}),(function(e){return!e.fullHeight&&"\n    height: fit-content;\n  "}),(function(e){return e.maxHeight&&"\n    max-height: ".concat(e.maxHeight,";\n  ")}),(function(e){return e.minWidth&&"\n    min-width: ".concat(e.minWidth,"px;\n\n    @media (max-width: ").concat(e.minWidth,"px) {\n      min-width: 0;\n    }\n  ")}),(function(e){return e.borderless&&"\n    border: none;\n  "}),(function(e){return e.overflowVisible&&"\n    overflow: visible;\n  "})),g=i.default.div.withConfig({displayName:"Panel__HeaderStyle",componentId:"sc-1ct8cgl-1"})(["border-top-left-radius:","px;border-top-right-radius:","px;"," "," "," ",""],a.n_,a.n_,(function(e){return"\n    background-color: ".concat((e.theme.background||c.Z.background).chartBlock,";\n    border-bottom: 1px solid ").concat((e.theme.interactive||c.Z.interactive).defaultBorder,";\n  ")}),(function(e){return e.height&&"\n    height: ".concat(e.height,"px;\n  ")}),s,(function(e){return e.headerPaddingVertical&&"\n    padding-bottom: ".concat(e.headerPaddingVertical,"px;\n    padding-top: ").concat(e.headerPaddingVertical,"px;\n  ")})),p=i.default.div.withConfig({displayName:"Panel__ContentStyle",componentId:"sc-1ct8cgl-2"})(["overflow-y:auto;padding:","px;height:100%;"," "," "," "," ",""],1.75*u.iI,l.w5,(function(e){return e.height&&"\n    height: ".concat(e.height,"px;\n  ")}),(function(e){return e.maxHeight&&"\n    max-height: calc(".concat(e.maxHeight," - ").concat(15*u.iI,"px);\n  ")}),(function(e){return e.noPadding&&"\n    padding: 0;\n  "}),(function(e){return e.overflowVisible&&"\n    overflow: visible;\n  "})),x=i.default.div.withConfig({displayName:"Panel__FooterStyle",componentId:"sc-1ct8cgl-3"})(["border-style:",";border-top-width:","px;padding:","px;"],a.M8,a.YF,1.75*u.iI);n.Z=function(e){var n=e.borderless,t=e.children,i=e.containerRef,c=e.contentContainerRef,a=e.footer,l=e.fullHeight,u=void 0===l||l,s=e.header,m=e.headerHeight,b=e.headerIcon,v=e.headerPaddingVertical,w=e.headerTitle,_=e.maxHeight,P=e.noPadding,Z=e.overflowVisible,j=e.subtitle,I=e.minWidth;return(0,h.jsxs)(f,{borderless:n,fullHeight:u,maxHeight:_,minWidth:I,overflowVisible:Z,ref:i,children:[(s||w)&&(0,h.jsxs)(g,{headerPaddingVertical:v,height:m,children:[s&&s,w&&(0,h.jsx)(r.Z,{alignItems:"center",justifyContent:"space-between",children:(0,h.jsxs)(r.Z,{alignItems:"center",children:[b&&b,(0,h.jsx)(d.Z,{ml:b?1:0,children:(0,h.jsx)(o.ZP,{bold:!0,default:!0,children:w})})]})})]}),(0,h.jsxs)(p,{maxHeight:_,noPadding:P,overflowVisible:Z,ref:c,children:[j&&(0,h.jsx)(d.Z,{mb:2,children:(0,h.jsx)(o.ZP,{default:!0,children:j})}),t]}),a&&(0,h.jsx)(x,{children:a})]})}},96283:function(e,n,t){"use strict";t.r(n);var i=t(77837),r=t(38860),d=t.n(r),o=t(29237),c=t(41788),a=t(30775),l=t(86673),u=t(20582),h=t(82531),s=t(49125),f=t(79585),g=t(9736),p=t(28598);function x(){var e=((0,g.PR)()||{}).id,n=h.ZP.users.detail(e).data,t=null===n||void 0===n?void 0:n.user;return(0,p.jsx)(a.Z,{uuidItemSelected:f.DQ,uuidWorkspaceSelected:f.tC,children:(0,p.jsx)(l.Z,{p:s.cd,children:(0,p.jsx)(o.Z,{children:(0,p.jsx)(u.Z,{disabledFields:["roles"],user:t})})})})}x.getInitialProps=(0,i.Z)(d().mark((function e(){return d().wrap((function(e){for(;;)switch(e.prev=e.next){case 0:return e.abrupt("return",{});case 1:case"end":return e.stop()}}),e)}))),n.default=(0,c.Z)(x)},10736:function(e,n,t){(window.__NEXT_P=window.__NEXT_P||[]).push(["/settings/account/profile",function(){return t(96283)}])}},function(e){e.O(0,[3850,9767,3573,434,9898,5477,9774,2888,179],(function(){return n=10736,e(e.s=n);var n}));var n=e.O();_N_E=n}]);